@@ -4,22 +4,19 @@
 
     Docutils transforms used by Sphinx when reading documents.
 
-    :copyright: Copyright 2007-2019 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2020 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
-from typing import cast
+from typing import Any, Dict, List, cast
 
 from docutils import nodes
+from docutils.nodes import Node
 
 from sphinx import addnodes
+from sphinx.application import Sphinx
 from sphinx.transforms import SphinxTransform
 
-if False:
-    # For type annotation
-    from typing import Any, Dict, List  # NOQA
-    from sphinx.application import Sphinx  # NOQA
-
 
 class RefOnlyListChecker(nodes.GenericNodeVisitor):
     """Raise `nodes.NodeFound` if non-simple list item is encountered.
@@ -28,17 +25,14 @@ class RefOnlyListChecker(nodes.GenericNodeVisitor):
     single reference in it.
     """
 
-    def default_visit(self, node):
-        # type: (nodes.Node) -> None
+    def default_visit(self, node: Node) -> None:
         raise nodes.NodeFound
 
-    def visit_bullet_list(self, node):
-        # type: (nodes.bullet_list) -> None
+    def visit_bullet_list(self, node: nodes.bullet_list) -> None:
         pass
 
-    def visit_list_item(self, node):
-        # type: (nodes.list_item) -> None
-        children = []  # type: List[nodes.Node]
+    def visit_list_item(self, node: nodes.list_item) -> None:
+        children = []  # type: List[Node]
         for child in node.children:
             if not isinstance(child, nodes.Invisible):
                 children.append(child)
@@ -53,8 +47,7 @@ class RefOnlyListChecker(nodes.GenericNodeVisitor):
             raise nodes.NodeFound
         raise nodes.SkipChildren
 
-    def invisible_visit(self, node):
-        # type: (nodes.Node) -> None
+    def invisible_visit(self, node: Node) -> None:
         """Invisible nodes should be ignored."""
         pass
 
@@ -67,13 +60,11 @@ class RefOnlyBulletListTransform(SphinxTransform):
     """
     default_priority = 100
 
-    def apply(self, **kwargs):
-        # type: (Any) -> None
+    def apply(self, **kwargs: Any) -> None:
         if self.config.html_compact_lists:
             return
 
-        def check_refonly_list(node):
-            # type: (nodes.Node) -> bool
+        def check_refonly_list(node: Node) -> bool:
             """Check for list with only references in it."""
             visitor = RefOnlyListChecker(self.document)
             try:
@@ -93,8 +84,7 @@ class RefOnlyBulletListTransform(SphinxTransform):
                     item.replace(para, compact_para)
 
 
-def setup(app):
-    # type: (Sphinx) -> Dict[str, Any]
+def setup(app: Sphinx) -> Dict[str, Any]:
     app.add_transform(RefOnlyBulletListTransform)
 
     return {
